@@ -5,7 +5,7 @@ BEGIN {
 # ABSTRACT: A bundle of MIDI and music modules
 use strict;
 use warnings;
-our $VERSION = '0.0502';
+our $VERSION = '0.06';
 1;
 
 __END__
@@ -20,7 +20,7 @@ Task::MusicBundle - A bundle of MIDI and music modules
 
 =head1 VERSION
 
-version 0.0502
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -48,14 +48,6 @@ included for the same reason.
 
 Task::MusicBundle - A bundle of MIDI and music modules
 
-=head1 VERSION
-
-version 0.0501
-
-=head1 NAME
-
-Task::MusicBundle - A bundle of MIDI and music modules
-
 =head1 CONTENTS
 
 L<Acme::Vuvuzela>
@@ -108,8 +100,6 @@ L<Music::LilyPondUtil>
 
 L<Music::NeoRiemannianTonnetz>
 
-L<Music::PitchNum>
-
 L<Music::Scala>
 
 L<Music::Scales> - Aug 08, 2003
@@ -118,7 +108,7 @@ L<Music::Tempo> - Aug 08, 2003
 
 L<Music::Tension>
 
-L<Music::Voss>
+L<Music::VoiceGen>
 
 L<Text::Chord::Piano>
 
@@ -140,6 +130,8 @@ L<MIDI::XML> - Jan 24, 2003 - This has Tk as a dependency - for an XML module. S
 
 L<Music::Image::Chord> - Oct 03, 2003,
 
+L<Music::PitchNum>
+
 L<PDL::Audio>,
 
 L<POE::Framework::MIDI> - Mar 19, 2006,
@@ -156,28 +148,6 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 AUTHOR
-
-Gene Boggs <gene@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Gene Boggs.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 AUTHOR
-
-Gene Boggs <gene@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
 This software is copyright (c) 2016 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
